/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2020-2024. All rights reserved.
 */

#ifndef DPC_IMPL_TYPE_POSE_H
#define DPC_IMPL_TYPE_POSE_H

#include "dpc/impl_type_vector3d.h"
#include "dpc/impl_type_quaternionf.h"

namespace dpc {
struct Pose {
    ::dpc::Vector3d position;
    ::dpc::Quaternionf orientation;

    static bool IsPlane()
    {
        return true;
    }


    using IsEnumerableTag = void;
    template<typename F>
    void enumerate(F& fun)
    {
        fun(position);
        fun(orientation);
    }

    template<typename F>
    void enumerate(F& fun) const
    {
        fun(position);
        fun(orientation);
    }

    template<typename F>
    void enumerate_internal(F& fun)
    {
        fun("position", position);
        fun("orientation", orientation);
    }

    template<typename F>
    void enumerate_internal(F& fun) const
    {
        fun("position", position);
        fun("orientation", orientation);
    }

    friend bool operator==(const ::dpc::Pose& lhs, const ::dpc::Pose& rhs) noexcept
    {
        return (lhs.position == rhs.position) && (lhs.orientation == rhs.orientation);
    }
};
} // namespace dpc


#endif // DPC_IMPL_TYPE_POSE_H
